@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2014 by Elvis Angelaccio <elvis.angelaccio@kde.org>
+    SPDX-FileCopyrightText: 2014 Elvis Angelaccio <elvis.angelaccio@kde.org>
 
-    This file is part of Kronometer.
-
-    Kronometer is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    Kronometer is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with Kronometer.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "stopwatch.h"
@@ -57,7 +44,7 @@ int Stopwatch::raw() const
 
 bool Stopwatch::initialize(int rawData)
 {
-    if (not isInactive() or rawData <= 0) {
+    if (!isInactive() || rawData <= 0) {
         return false;
     }
 
@@ -102,6 +89,7 @@ void Stopwatch::reset()
 {
     m_elapsedTimer.invalidate();          // if state is running, it will emit a zero time at next timerEvent() call
     QCoreApplication::processEvents();
+    m_accumulator = 0;
     emit time(0);
     m_state = State::Inactive;
     emit inactive();
